---
name: "✨ Feature Request"
about: Suggest some awesome ideas for this project
title: "[FR] Feature Name"
labels: ''
assignees: ''

---

<div align="center">

# Feature Request
— Feature Name

</div>

**What's the problem you've been dealing or frustrated with?**

Example: handlers, logs, etc.

**Describe the solution you'd like**
A clear and concise description of what you want to happen. Syntax examples or ideas are welcome.

Example:
```py
linelib.foo()
```

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or **screenshots** about the feature request here.
